# License: GPLv3 (GNU Public License version 3.0)
import numpy as np
import pyvista as pv
import itk

ref_vti = pv.UniformGrid("tmp_gmsh.vti")
ref_vti.save("tmp_ref_vti.vti")
print("tmp_ref_vti.vti")

# * Convert grid into ITK images
image_type = itk.Image[itk.F, 3]
nx, ny, nz = [val - 1 for val in ref_vti.dimensions]
fixed_image_arr = np.reshape(
    ref_vti.cell_data["material"], [nz, nx, ny])
fixed_image = itk.image_from_array(
    fixed_image_arr.astype(np.float32), ttype=image_type)

# # Does not work:
#
# itk.image_from_vtk_image(ref_vti)
#
# # Result:
# #   File "/home/edgar/.local/lib/python3.10/site-packages/itk/support/extras.py", line 746, in image_from_vtk_image
# #     array = vtk_to_numpy(point_data.GetScalars())
# #   File "/usr/lib/python3.10/site-packages/vtkmodules/util/numpy_support.py", line 215, in vtk_to_numpy
# #   AttributeError: 'NoneType' object has no attribute 'GetDataType'

# Trying to set the right dimensions on the grid
fixed_image.SetSpacing(ref_vti.spacing)
fixed_image.SetOrigin(ref_vti.GetOrigin())

# * Save VTK
first_frame_vtk = "tmp_itk_reference.vtk"
itk.imwrite(fixed_image, first_frame_vtk)
print(first_frame_vtk)
np.savez(first_frame_vtk.replace(".vtk", ".npz"),
         fixed_image_arr)

# | itk                       |                  5.3.0 |
# | itk-core                  |                  5.3.0 |
# | itk-elastix               |                 0.15.0 |
# | itk-filtering             |                  5.3.0 |
# | itk-io                    |                  5.3.0 |
# | itk-meshtopolydata        |                 0.10.0 |
# | itk-minimalpathextraction |                  1.2.4 |
# | itk-numerics              |                  5.3.0 |
# | itk-registration          |                  5.3.0 |
# | itk-segmentation          |                  5.3.0 |
# | itk-strain                |                  0.3.6 |
# | itk-tubetk                |                  1.3.4 |
# | itkwidgets                |                 0.32.5 |
# | numpy                     |                 1.24.1 |
# | pyvista                   |                 0.37.0 |
# | scipy                     |                 1.10.0 |

# feed_vti_into_dvc.py ends here
